//------------------------------------------------------------------
/*
	Main.c

	Top level program file.
	See description in the Read_Me.txt document.

*/
//------------------------------------------------------------------
// Constants and global variables
#include <constants.h>
#include <globals.h>
// C libraries
#include <propeller.h>
#include <stdio.h>
#include <asio.h>

//------------------------------------------------------------------
// Protoypes of external routines
void APD_Control(void);										// Controls.c
void Tex_Control(void);										// Controls.c
void User_Action(void);										// Serial.c
void Raw_Display(void);										// Serial.c
void Fast_Display(void);									// Serial.c
void Control_Display(void);								// Serial.c
void Distances_Display(void);							// Serial.c
void Print_Line(int length);							// Serial.c
int SPI(void);														// SPI.c
void Initialise_Hardware(void);						// Utilities.c
void Initialise_Parameters(void);					// Utilities.c
void BlinkLED(void);											// Utilities.c
void Flash(int pin);											// Utilities.c

void Convert_to_Distance(void);						// Utilities.c

//------------------------------------------------------------------ START
void main()
	{
 	Initialise_Hardware();									// Configure the Prop hardware
	Initialise_Parameters();								// Initialise software parameters
	BlinkLED();															// Intro light and sound
 	printf("\rDS00VQ100 LRF #%05d\r", serial_number);	// Intro comms to PC	
	Print_Line(20);

	while (1)																// Main loop
		{
		if(rx_flag == READY)									// Check for key press on comms port (flag set by different cog)
			{
			Flash(BUZZER);											// Enunciate using buzzer
			User_Action();											// Take action if key pressed
			rx_flag = -1;												// Clear key press flag when user action is completed
			putchar('\r');											// New line
			}
		
		if(SPI() == READY)										// Check for result from DS00VQ100 chip
			{																		// and store results ready for further action
			Convert_to_Distance();							// Convert chip data into meters and apply calibrations
			APD_Control();											// Control APD noise if necessary
			Tex_Control();											// Control time expansion if necessary
			
			switch (h2m_mode)										// Check which display mode is active
        {
        case 'c':
          Control_Display();							// Show values associated with the control loops
        break;
        case 'd':
          Distances_Display();						// Show intermediate distance values
        break;
        case 'r':
          Raw_Display();									// Show data directly from DS00VQ100 chip
        break;
				case 's':													// Show the settings display, this is a static display
				break;														// that doesn't update when new distance results become available
        default:													//	'f'
          Fast_Display();									// Show the final distance result only
        break;
        }
			}
		}
	}
//------------------------------------------------------------------ END